@@ -23,7 +23,7 @@ from werkzeug.utils import import_string
 
 from flask_caching._compat import PY2, iteritems
 
-__version__ = "1.6.0"
+__version__ = "1.7.0"
 
 logger = logging.getLogger(__name__)
 
@@ -287,6 +287,7 @@ class Cache(object):
         key_prefix="view/%s",
         unless=None,
         forced_update=None,
+        response_filter=None,
         query_string=False,
         hash_method=hashlib.md5,
     ):
@@ -352,6 +353,14 @@ class Cache(object):
                               cache value will be updated regardless cache
                               is expired or not. Useful for background
                               renewal of cached functions.
+
+        :param response_filter: Default None. If not None, the callable is
+                                invoked after the cached funtion evaluation,
+                                and is given one arguement, the response
+                                content. If the callable returns False, the
+                                content will not be cached. Useful to prevent
+                                caching of code 500 responses.
+
         :param query_string: Default False. When True, the cache key
                              used will be the result of hashing the
                              ordered query string parameters. This
@@ -360,6 +369,7 @@ class Cache(object):
                              were passed in a different order. See
                              _make_cache_key_query_string() for more
                              details.
+
         :param hash_method: Default hashlib.md5. The hash method used to
                             generate the keys for cached results.
 
@@ -388,24 +398,26 @@ class Cache(object):
                     if self.app.debug:
                         raise
                     logger.exception(
-                        "Exception possibly due to " "cache backend."
+                        "Exception possibly due to cache backend."
                     )
                     return f(*args, **kwargs)
 
                 if rv is None:
                     rv = f(*args, **kwargs)
-                    try:
-                        self.cache.set(
-                            cache_key,
-                            rv,
-                            timeout=decorated_function.cache_timeout,
-                        )
-                    except Exception:
-                        if self.app.debug:
-                            raise
-                        logger.exception(
-                            "Exception possibly due to " "cache backend."
-                        )
+
+                    if response_filter is None or response_filter(rv):
+                        try:
+                            self.cache.set(
+                                cache_key,
+                                rv,
+                                timeout=decorated_function.cache_timeout,
+                            )
+                        except Exception:
+                            if self.app.debug:
+                                raise
+                            logger.exception(
+                                "Exception possibly due to cache backend."
+                            )
                 return rv
 
             def make_cache_key(*args, **kwargs):
@@ -749,7 +761,7 @@ class Cache(object):
                     if self.app.debug:
                         raise
                     logger.exception(
-                        "Exception possibly due to " "cache backend."
+                        "Exception possibly due to cache backend."
                     )
                     return f(*args, **kwargs)
 
@@ -765,7 +777,7 @@ class Cache(object):
                         if self.app.debug:
                             raise
                         logger.exception(
-                            "Exception possibly due to " "cache backend."
+                            "Exception possibly due to cache backend."
                         )
                 return rv
 
@@ -890,10 +902,9 @@ class Cache(object):
             backend.
         """
         if not callable(f):
-            raise DeprecationWarning(
-                "Deleting messages by relative name is "
-                "no longer reliable, please switch to a "
-                "function reference."
+            raise TypeError(
+                "Deleting messages by relative name is not supported, please"
+                "use a function reference."
             )
 
         if not (args or kwargs):
@@ -914,10 +925,9 @@ class Cache(object):
             in the cache backend.
         """
         if not callable(f):
-            raise DeprecationWarning(
-                "Deleting messages by relative name is "
-                "no longer reliable, please use a "
-                "function reference."
+            raise TypeError(
+                "Deleting messages by relative name is not supported, please"
+                "use a function reference."
             )
 
         self._memoize_version(f, delete=True)
